==> Do-1.02.tar.gz: Do-1.02/lib/Data/Object/Autobox/Float.pm <==
package Data::Object::Autobox::Float;

use 5.014;

use strict;
use warnings;

use Data::Object ();

our $VERSION = '1.02'; # VERSION

# BUILD

sub new {
  Data::Object->float(pop);
}

1;
=encoding utf8

=head1 NAME

Data::Object::Autobox::Float

=cut

=head1 ABSTRACT

Data-Object Autoboxing for Float Objects

=cut

=head1 SYNOPSIS

  use Data::Object::Autobox::Float;

=cut

=head1 DESCRIPTION

This package implements autoboxing via L<Data::Object::Autobox> for
L<Data::Object::Float> objects.

=cut

=head1 METHODS

This package implements the following methods.

=cut

=head2 new

  new(Float $arg1) : FloatObject

Construct a new object.

=over 4

=item new example

  my $float = Data::Object::Autobox::Float->new(1.23);

=back

=cut

=head1 AUTHOR

Al Newkirk, C<awncorp@cpan.org>

=head1 LICENSE

Copyright (C) 2011-2019, Al Newkirk, et al.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.

=head1 STATUS

=begin html

<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
</a>

=end html

=head1 SEE ALSO

To get the most out of this distribution, consider reading the following:

L<Data::Object::Class>

L<Data::Object::Role>

L<Data::Object::Rule>

L<Data::Object::Library>

L<Data::Object::Signatures>

L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>

L<GitHub|https://github.com/iamalnewkirk/data-object>

=cut

==> Do-1.03.tar.gz: Do-1.03/lib/Data/Object/Autobox/Float.pm <==
package Data::Object::Autobox::Float;

use 5.014;

use strict;
use warnings;

use Data::Object ();

our $VERSION = '1.03'; # VERSION

# BUILD

sub new {
  Data::Object->float(pop);
}

1;

=encoding utf8

=head1 NAME

Data::Object::Autobox::Float

=cut

=head1 ABSTRACT

Data-Object Autoboxing for Float Objects

=cut

=head1 SYNOPSIS

  use Data::Object::Autobox::Float;

=cut

=head1 DESCRIPTION

This package implements autoboxing via L<Data::Object::Autobox> for
L<Data::Object::Float> objects.

=cut

=head1 METHODS

This package implements the following methods.

=cut

=head2 new

  new(Float $arg1) : FloatObject

Construct a new object.

=over 4

=item new example

  my $float = Data::Object::Autobox::Float->new(1.23);

=back

=cut

=head1 AUTHOR

Al Newkirk, C<awncorp@cpan.org>

=head1 LICENSE

Copyright (C) 2011-2019, Al Newkirk, et al.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.

=head1 STATUS

=begin html

<a href="https://travis-ci.org/iamalnewkirk/do" target="_blank">
<img src="https://travis-ci.org/iamalnewkirk/do.svg?branch=master"/>
</a>

=end html

=head1 SEE ALSO

To get the most out of this distribution, consider reading the following:

L<Data::Object::Class>

L<Data::Object::Role>

L<Data::Object::Rule>

L<Data::Object::Library>

L<Data::Object::Signatures>

L<Contributing|https://github.com/iamalnewkirk/do/README-DEVEL.mkdn>

L<GitHub|https://github.com/iamalnewkirk/do>

=cut
